/*
 * @Descripttion:
 * @version:
 * @Author: kBank
 * @Date: 2023-03-02 09:26:59
 */
import request from '@/utils/request'

// 货币种类枚举列表
export function accountList() {
  return request({
    url: '/system/pub/enums/account',
    method: 'get'
  })
}

// 货币种类枚举列表
export function currencyType() {
  return request({
    url: '/system/pub/enums/currency-type',
    method: 'get'
  })
}

// 隶属体系
export function vertexList() {
  return request({
    url: '/system/manage/vertex/find-all',
    method: 'get'
  })
}

// 隶属团队
export function memberTeam() {
  return request({
    url: '/member/manage/member-team/list',
    method: 'get'
  })
}

// 业绩汇总
export function memberStructure(params) {
  return request({
    url: '/member/manage/member-structure/list',
    method: 'get',
    params
  })
}

// 安置数据
export function getShowPlace(data, data1) {
  return request({
    url: '/member/manager/center/show-place' + data1,
    method: 'post',
    data
  })
}

// 推荐数据
export function getShowRecommend(data, data1) {
  return request({
    url: '/member/manager/center/show-recommend' + data1,
    method: 'post',
    data
  })
}

// 产品编辑
export function productUpdate(data) {
  return request({
    url: '/sale/manage/product/update',
    method: 'post',
    data
  })
}

// 更新团队信息
export function updateTeams(data) {
  return request({
    url: '/member/manage/member-team/update-team/' + data,
    method: 'get'
  })
}

// 更新体系信息
export function updateVertexs(data) {
  return request({
    url: '/system/manage/vertex/update-vertex/' + data,
    method: 'get'
  })
}

// 户籍变更列表
export function getDomicileChangeList(data) {
  return request({
    url: '/member/manage/change-domicile/domicile-change-list',
    method: 'post',
    data
  })
}

// 户籍变更驳回
export function domicileReject(data) {
  return request({
    url: '/member/manage/change-domicile/domicile-change-reject',
    method: 'post',
    data
  })
}

// 户籍变更查看详情
export function DomicileDetails(params) {
  return request({
    url: '/member/manage/change-domicile/domicile-change-detail',
    method: 'get',
    params
  })
}

// 户籍变更签呈
export function signType(data) {
  return request({
    url: '/member/manage/change-domicile/domicile-change-agree',
    method: 'get',
    data
  })
}

// 会员目标类型
export function goalsType() {
  return request({
    url: '/system/pub/enums/goals-type',
    method: 'get'
  })
}

// 会员目标分类
export function goalsClassify() {
  return request({
    url: '/system/pub/enums/goals-Classify',
    method: 'get'
  })
}

// 获取菜单路由
export function getRouters() {
  return request({
    url: '/system/manage/menu/get-routers',
    method: 'get'
  })
}

// 奖金波比柱状图
export function pillarRatio(params) {
  return request({
    url: '/member/manage/bonus-statis/pillarRatio',
    method: 'get',
    params
  })
}

// 奖金波比饼
export function pieChartRatio(params) {
  return request({
    url: '/member/manage/bonus-statis/pieChartRatio',
    method: 'get',
    params
  })
}

// 奖金波比列表
export function bonusList(params) {
  return request({
    url: '/member/manage/bonus-statis/list',
    method: 'get',
    params
  })
}

// 奖金波比列表统计
export function bonusListHistory(params) {
  return request({
    url: '/member/manage/bonus-statis/statis-history',
    method: 'get',
    params
  })
}

// 奖金波比图表
export function bonusListChart(params) {
  return request({
    url: '/member/manage/bonus-statis/chart',
    method: 'get',
    params
  })
}

// 奖金波比图表合计
export function bonusListChartSum(params) {
  return request({
    url: '/member/manage/bonus-statis/chartSum',
    method: 'get',
    params
  })
}

// 安置图表
export function placeImg(data) {
  return request({
    url: '/member/manager/center/show-place-image',
    method: 'post',
    data
  })
}

// 隶属团队
export function listNoPage(params) {
  return request({
    url: '/member/manage/member-team/listNoPage',
    method: 'get',
    params
  })
}

// 拨比列表小计
export function subtotal(params) {
  return request({
    url: '/member/manage/bonus-statis/subtotal',
    method: 'get',
    params
  })
}

// 拨比列表体系
export function vertexChild(params) {
  return request({
    url: '/system/manage/vertex/vertex-child',
    method: 'get',
    params
  })
}

// 个人伞下拨币查询列表
export function getPersonStatList(params) {
  return request({
    url: '/member/manage/bonus-statis/singlePersonList',
    method: 'get',
    params
  })
}

// 证件状态
export function certificate_status(params) {
  return request({
    url: '/system/pub/enums/certificate_status',
    method: 'get',
    params
  })
}

// 查询4-n配置
export function touchQuery(data) {
  return request({
    url: '/bonus/expand/touch/query?pageNum=' + data.pageNum + '&pageSize=' + data.pageSize,
    method: 'post',
    data
  })
}

// 4-n配置修改
export function touchSave(data) {
  return request({
    url: '/bonus/expand/touch/save',
    method: 'post',
    data
  })
}

// 重算4-n碰次
export function touchRepeat(data) {
  return request({
    url: '/bonus/expand/touch/repeat',
    method: 'post',
    data
  })
}

// 4-n配置公布
export function settleBonus(params) {
  return request({
    url: '/bonus/manage/settle/settle-bonus',
    method: 'get',
    params
  })
}

// 4-n配置title
export function queryTitle(params) {
  return request({
    url: '/bonus/expand/touch/query-title',
    method: 'get',
    params
  })
}

// 顶点下拉选
export function topVertexList(params) {
  return request({
    url: '/member/manage/bonus-vertex-statis/vertexList',
    method: 'get',
    params
  })
}

// top拨比列表
export function topBonusList(params) {
  return request({
    url: '/member/manage/bonus-vertex-statis/list',
    method: 'get',
    params
  })
}

// top拨比列表小计
export function topSubtotal(params) {
  return request({
    url: '/member/manage/bonus-vertex-statis/subtotal',
    method: 'get',
    params
  })
}

// top奖金波比列表统计
export function topBonusListHistory(params) {
  return request({
    url: '/member/manage/bonus-vertex-statis/statis-history',
    method: 'get',
    params
  })
}
// 乐享奖金波比列表统计
export function topBonusLenListHistory(params) {
  return request({
    url: '/member/manage/bonus-len-statis/statis-history',
    method: 'get',
    params
  })
}
// 乐享奖金波比列表合计
export function bonusLenSubtotal(params) {
  return request({
    url: '/member/manage/bonus-len-statis/subtotal',
    method: 'get',
    params
  })
}
// 顶点拨比汇总列表
export function bonusVertex(params) {
  return request({
    url: '/member/manage/bonus-vertex-total-statis/list',
    method: 'get',
    params
  })
}
// 乐享顶点拨比列表
export function bonusLenStatis(params) {
  return request({
    url: '/member/manage/bonus-len-statis/list',
    method: 'get',
    params
  })
}

// 拓展延缓列表
export function expansionDelayList(params) {
  return request({
    url: '/bonus/manage/bonus-delay/delay-list',
    method: 'get',
    params
  })
}
